@@ -3,7 +3,7 @@ createqual <-
 function (name, description, status, keywords = NULL, retry.delay = NULL, 
     test = NULL, answerkey = NULL, test.duration = NULL,
     validate.test = FALSE, validate.answerkey = FALSE,
-    auto = NULL, auto.value = NULL, verbose = getOption('MTurkR.verbose'), ...) {
+    auto = NULL, auto.value = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...) {
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
@@ -70,7 +70,10 @@ function (name, description, status, keywords = NULL, retry.delay = NULL,
     if(is.null(request$valid))
         return(request)
     if(request$valid == TRUE) {
+        s <- getOption("stringsAsFactors")
+        options("stringsAsFactors" = FALSE)
         QualificationType <- as.data.frame.QualificationTypes(xml.parsed = xmlParse(request$xml))
+        options("stringsAsFactors" = s)
         if(verbose)
             message("QualificationType Created: ", QualificationType$QualificationTypeId[1])
         return(QualificationType)
