@@ -1,6 +1,6 @@
 DisposeQualificationType <-
 disposequal <-
-function (qual, verbose = getOption('MTurkR.verbose'), ...) {
+function (qual, verbose = getOption('MTurkR.verbose', TRUE), ...) {
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
